/// <reference types="node" />
/// <reference types="node" />
import Color from 'color';
import stream from 'stream';
export default class SvgFill {
    private _fillColor;
    constructor(fillColor: Color | string);
    setFillColor(fillColor: Color | string): void;
    getFillColor(): Color;
    /**
     * Fills all shapes in the SVG with the fill color.
     *
     * Note, this is currently a naive solution that simply adds a fill
     * attribute with the chosen fill color to the SVG element. For SVGs
     * without styling attributes, such as ones to be composed into
     * a symbol sprite, this should work fine. For anything else, the
     * results will be hit and miss.
     *
     * @param svgData A string or buffer containing valid SVG data.
     */
    fillSvg(svgData: Buffer | string): string;
    /**
     * Returns a transform stream that the SVG data can be
     * piped into. It will output the filled SVG data.
     *
     * Note: This function is primarily for developer convenience.
     * Internally, it waits until the entire SVG data has been received,
     * before doing the transform and outputting it. Therefore, you
     * don't really reap the benefits of streams, as any consumer will be
     * stuck waiting until the full SVG data has been buffered and
     * transformed.
     */
    fillSvgStream(): stream.Transform;
}
